@@ -44,6 +44,8 @@ class Node(resource.Resource):
     cluster_id = resource.Body('cluster_id')
     #: The ID of the profile used by this node.
     profile_id = resource.Body('profile_id')
+    #: The domain ID of the node.
+    domain_id = resource.Body('domain')
     #: The ID of the user who created this node.
     user_id = resource.Body('user')
     #: The ID of the project this node belongs to.
@@ -125,6 +127,35 @@ class Node(resource.Resource):
                             json={operation: params})
         return resp.json()
 
+    def adopt(self, session, preview=False, **params):
+        """Adopt a node for management.
+
+        :param session: A session object used for sending request.
+        :param preview: A boolean indicating whether the adoption is a
+                        preview. A "preview" does not create the node object.
+        :param dict params: A dict providing the details of a node to be
+                            adopted.
+        """
+        if preview:
+            path = 'adopt-preview'
+            attrs = {
+                'identity': params.get('identity'),
+                'overrides': params.get('overrides'),
+                'type': params.get('type'),
+                'snapshot': params.get('snapshot')
+            }
+        else:
+            path = 'adopt'
+            attrs = params
+
+        url = utils.urljoin(self.base_path, path)
+        resp = session.post(url, endpoint_filter=self.service, json=attrs)
+        if preview:
+            return resp.json()
+
+        self._translate_response(resp)
+        return self
+
 
 class NodeDetail(Node):
     base_path = '/nodes/%(node_id)s?show_details=True'
