@@ -30,13 +30,19 @@ class Profile(resource.Resource):
     patch_update = True
 
     _query_mapping = resource.QueryParameters(
-        'name', 'type', 'metadata')
+        'sort', 'global_project', 'type', 'name')
 
     # Bodyerties
     #: The name of the profile
     name = resource.Body('name')
     #: The type of the profile.
-    type_name = resource.Body('type')
+    type = resource.Body('type')
+    #: The ID of the project this profile belongs to.
+    project_id = resource.Body('project')
+    #: The domain ID of the profile.
+    domain_id = resource.Body('domain')
+    #: The ID of the user who created this profile.
+    user_id = resource.Body('user')
     #: The spec of the profile.
     spec = resource.Body('spec', type=dict)
     #: A collection of key-value pairs that are attached to the profile.
@@ -45,3 +51,14 @@ class Profile(resource.Resource):
     created_at = resource.Body('created_at')
     #: Timestamp of when the profile was last updated.
     updated_at = resource.Body('updated_at')
+
+
+class ProfileValidate(Profile):
+    base_path = '/profiles/validate'
+    allow_create = True
+    allow_get = False
+    allow_update = False
+    allow_delete = False
+    allow_list = False
+
+    patch_update = False
