@@ -274,6 +274,16 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         body = {"removeFloatingIp": {"address": address}}
         self._action(session, body)
 
+    def backup(self, session, name, backup_type, rotation):
+        body = {
+            "createBackup": {
+                "name": name,
+                "backup_type": backup_type,
+                "rotation": rotation
+            }
+        }
+        self._action(session, body)
+
     def pause(self, session):
         body = {"pause": None}
         self._action(session, body)
@@ -336,6 +346,27 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         body = {"unshelve": None}
         self._action(session, body)
 
+    def migrate(self, session):
+        body = {"migrate": None}
+        self._action(session, body)
+
+    def get_console_output(self, session, length=None):
+        body = {"os-getConsoleOutput": {}}
+        if length is not None:
+            body["os-getConsoleOutput"]["length"] = length
+        resp = self._action(session, body)
+        return resp.json()
+
+    def live_migrate(self, session, host, force):
+        body = {
+            "os-migrateLive": {
+                "host": host,
+                "block_migration": "auto",
+                "force": force
+            }
+        }
+        self._action(session, body)
+
 
 class ServerDetail(Server):
     base_path = '/servers/detail'
