@@ -11,7 +11,7 @@
 # under the License.
 
 from openstack.compute import compute_service
-from openstack import resource
+from openstack import resource2 as resource
 
 
 class Version(resource.Resource):
@@ -26,6 +26,6 @@ class Version(resource.Resource):
     allow_list = True
 
     # Properties
-    links = resource.prop('links')
-    status = resource.prop('status')
-    updated = resource.prop('updated')
+    links = resource.Body('links')
+    status = resource.Body('status')
+    updated = resource.Body('updated')
