@@ -521,12 +521,11 @@ class Resource(object):
 
         uri = self.base_path % self._uri.attributes
         if requires_id:
-            id = self._get_id(self)
-            if id is None:
+            if self.id is None:
                 raise exceptions.InvalidRequest(
                     "Request requires an ID but none was found")
 
-            uri = utils.urljoin(uri, id)
+            uri = utils.urljoin(uri, self.id)
 
         return _Request(uri, body, headers)
 
@@ -645,6 +644,9 @@ class Resource(object):
         :raises: :exc:`~openstack.exceptions.MethodNotSupported` if
                  :data:`Resource.allow_update` is not set to ``True``.
         """
+        # The id cannot be dirty for an update
+        self._body._dirty.discard("id")
+
         # Only try to update if we actually have anything to update.
         if not any([self._body.dirty, self._header.dirty]):
             return self
