@@ -41,6 +41,7 @@ EXAMPLE = {
     'status': '17',
     'subnets': ['18', '19'],
     'updated_at': '2016-07-09T12:14:57.233772',
+    'vlan_transparent': False,
 }
 
 
@@ -92,16 +93,40 @@ class TestNetwork(testtools.TestCase):
         self.assertEqual(EXAMPLE['status'], sot.status)
         self.assertEqual(EXAMPLE['subnets'], sot.subnet_ids)
         self.assertEqual(EXAMPLE['updated_at'], sot.updated_at)
+        self.assertEqual(EXAMPLE['vlan_transparent'], sot.is_vlan_transparent)
+
+        self.assertDictEqual(
+            {'limit': 'limit',
+             'marker': 'marker',
+             'description': 'description',
+             'name': 'name',
+             'project_id': 'project_id',
+             'status': 'status',
+             'ipv4_address_scope_id': 'ipv4_address_scope',
+             'ipv6_address_scope_id': 'ipv6_address_scope',
+             'is_admin_state_up': 'admin_state_up',
+             'is_port_security_enabled': 'port_security_enabled',
+             'is_router_external': 'router:external',
+             'is_shared': 'shared',
+             'provider_network_type': 'provider:network_type',
+             'provider_physical_network': 'provider:physical_network',
+             'provider_segmentation_id': 'provider:segmentation_id',
+             'tags': 'tags',
+             'any_tags': 'tags-any',
+             'not_tags': 'not-tags',
+             'not_any_tags': 'not-tags-any',
+             },
+            sot._query_mapping._mapping)
 
 
-class TestNetworkHostingDHCPAgent(testtools.TestCase):
+class TestDHCPAgentHostingNetwork(testtools.TestCase):
 
     def test_basic(self):
-        net = network.NetworkHostingDHCPAgent()
-        self.assertEqual('agent', net.resource_key)
-        self.assertEqual('agents', net.resources_key)
-        self.assertEqual('/networks/%(network_id)s/dhcp-agents', net.base_path)
-        self.assertEqual('dhcp-agent', net.resource_name)
+        net = network.DHCPAgentHostingNetwork()
+        self.assertEqual('network', net.resource_key)
+        self.assertEqual('networks', net.resources_key)
+        self.assertEqual('/agents/%(agent_id)s/dhcp-networks', net.base_path)
+        self.assertEqual('dhcp-network', net.resource_name)
         self.assertEqual('network', net.service.service_type)
         self.assertFalse(net.allow_create)
         self.assertTrue(net.allow_get)
